@@ -25,42 +25,106 @@ test_that('stan_efftox passes ellipsis variables to rstan::sampling', {
   expect_equal(nrow(df), 500)
 })
 
-# test_that('stan_efftox_demo fits to zero patients', {
-#   x <- stan_efftox_demo(outcome_str = '')
-#   expect_equal(x$dat$num_patients, 0)
-#   expect_equal(length(x$dat$doses), 0)
-#   expect_equal(length(x$dat$tox), 0)
-#   expect_equal(length(x$dat$weights), 0)
-#   expect_equal(x$dat$num_doses, 5)
-# })
+test_that('stan_efftox_demo fits to zero patients', {
+  x <- stan_efftox_demo(outcome_str = '')
+  expect_equal(x$num_patients, 0)
+  expect_equal(length(x$doses), 0)
+  expect_equal(length(x$tox), 0)
+  expect_equal(length(x$dose_indices), 5)
+  expect_equal(n_at_dose(x), c(0, 0, 0, 0, 0))
+  expect_equal(tox_at_dose(x), c(0, 0, 0, 0, 0))
+  expect_equal(eff_at_dose(x), c(0, 0, 0, 0, 0))
+  l <- weights_at_dose(x)
+  expect_equal(length(l), 5)
+  expect_equal(l[[1]], numeric(0))
+  expect_equal(l[[2]], numeric(0))
+  expect_equal(l[[3]], numeric(0))
+  expect_equal(l[[4]], numeric(0))
+  expect_equal(l[[5]], numeric(0))
+  expect_equal(weights_at_dose(x, dose = 1), numeric(0))
+  expect_equal(weights_at_dose(x, dose = 2), numeric(0))
+  expect_equal(weights_at_dose(x, dose = 3), numeric(0))
+  expect_equal(weights_at_dose(x, dose = 4), numeric(0))
+  expect_equal(weights_at_dose(x, dose = 5), numeric(0))
+  expect_equal(total_weight_at_dose(x), c(0, 0, 0, 0, 0))
+})
 
 test_that('stan_efftox_demo fits to one patient', {
   x <- stan_efftox_demo(outcome_str = '1N')
-  expect_equal(x$dat$num_patients, 1)
-  expect_equal(length(x$dat$doses), 1)
-  expect_equal(length(x$dat$tox), 1)
-  expect_equal(length(x$dat$eff), 1)
-  expect_equal(x$dat$num_doses, 5)
+  expect_equal(x$num_patients, 1)
+  expect_equal(length(x$doses), 1)
+  expect_equal(length(x$tox), 1)
+  expect_equal(length(x$eff), 1)
+  expect_equal(length(x$dose_indices), 5)
+  expect_equal(n_at_dose(x), c(1, 0, 0, 0, 0))
+  expect_equal(tox_at_dose(x), c(0, 0, 0, 0, 0))
+  expect_equal(eff_at_dose(x), c(0, 0, 0, 0, 0))
+  l <- weights_at_dose(x)
+  expect_equal(length(l), 5)
+  expect_equal(l[[1]], c(1))
+  expect_equal(l[[2]], numeric(0))
+  expect_equal(l[[3]], numeric(0))
+  expect_equal(l[[4]], numeric(0))
+  expect_equal(l[[5]], numeric(0))
+  expect_equal(weights_at_dose(x, dose = 1), c(1))
+  expect_equal(weights_at_dose(x, dose = 2), numeric(0))
+  expect_equal(weights_at_dose(x, dose = 3), numeric(0))
+  expect_equal(weights_at_dose(x, dose = 4), numeric(0))
+  expect_equal(weights_at_dose(x, dose = 5), numeric(0))
+  expect_equal(total_weight_at_dose(x), c(1, 0, 0, 0, 0))
 })
 
 test_that('stan_efftox_demo fits to two patients in one cohort', {
   x <- stan_efftox_demo(outcome_str = '1NE')
-  expect_equal(x$dat$num_patients, 2)
-  expect_equal(length(x$dat$doses), 2)
-  expect_equal(length(x$dat$tox), 2)
-  expect_equal(length(x$dat$eff), 2)
-  expect_equal(x$dat$num_doses, 5)
+  expect_equal(x$num_patients, 2)
+  expect_equal(length(x$doses), 2)
+  expect_equal(length(x$tox), 2)
+  expect_equal(length(x$eff), 2)
+  expect_equal(length(x$dose_indices), 5)
+  expect_equal(n_at_dose(x), c(2, 0, 0, 0, 0))
+  expect_equal(tox_at_dose(x), c(0, 0, 0, 0, 0))
+  expect_equal(eff_at_dose(x), c(1, 0, 0, 0, 0))
+  l <- weights_at_dose(x)
+  expect_equal(length(l), 5)
+  expect_equal(l[[1]], c(1, 1))
+  expect_equal(l[[2]], numeric(0))
+  expect_equal(l[[3]], numeric(0))
+  expect_equal(l[[4]], numeric(0))
+  expect_equal(l[[5]], numeric(0))
+  expect_equal(weights_at_dose(x, dose = 1), c(1, 1))
+  expect_equal(weights_at_dose(x, dose = 2), numeric(0))
+  expect_equal(weights_at_dose(x, dose = 3), numeric(0))
+  expect_equal(weights_at_dose(x, dose = 4), numeric(0))
+  expect_equal(weights_at_dose(x, dose = 5), numeric(0))
+  expect_equal(total_weight_at_dose(x), c(2, 0, 0, 0, 0))
 })
 
 test_that('stan_efftox_demo fits to two patients in two cohorts', {
   x <- stan_efftox_demo(outcome_str = '1N 2E')
-  expect_equal(x$dat$num_patients, 2)
-  expect_equal(length(x$dat$doses), 2)
-  expect_equal(length(x$dat$tox), 2)
-  expect_equal(length(x$dat$eff), 2)
-  expect_equal(x$dat$num_doses, 5)
+  expect_equal(x$num_patients, 2)
+  expect_equal(length(x$doses), 2)
+  expect_equal(length(x$tox), 2)
+  expect_equal(length(x$eff), 2)
+  expect_equal(length(x$dose_indices), 5)
+  expect_equal(n_at_dose(x), c(1, 1, 0, 0, 0))
+  expect_equal(tox_at_dose(x), c(0, 0, 0, 0, 0))
+  expect_equal(eff_at_dose(x), c(0, 1, 0, 0, 0))
+  l <- weights_at_dose(x)
+  expect_equal(length(l), 5)
+  expect_equal(l[[1]], c(1))
+  expect_equal(l[[2]], c(1))
+  expect_equal(l[[3]], numeric(0))
+  expect_equal(l[[4]], numeric(0))
+  expect_equal(l[[5]], numeric(0))
+  expect_equal(weights_at_dose(x, dose = 1), c(1))
+  expect_equal(weights_at_dose(x, dose = 2), c(1))
+  expect_equal(weights_at_dose(x, dose = 3), numeric(0))
+  expect_equal(weights_at_dose(x, dose = 4), numeric(0))
+  expect_equal(weights_at_dose(x, dose = 5), numeric(0))
+  expect_equal(total_weight_at_dose(x), c(1, 1, 0, 0, 0))
 })
 
+
 # Accuracy checks ----
 # Recreate some known (i.e. independently calculated) output:
 test_that('Thall et al. (2014) model fits correctly to "1NNN 2ENN"', {
